@@ -279,6 +279,9 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
     } else if (property == QLatin1String("Interface")) {
         interfaceName = value.toString();
         Q_EMIT q->interfaceNameChanged();
+    } else if (property == QLatin1String("InterfaceFlags")) {
+        interfaceFlags = value.toUInt();
+        Q_EMIT q->interfaceFlagsChanged();
     } else if (property == QLatin1String("Ip4Address")) {
         ipV4Address = QHostAddress(ntohl(value.toUInt()));
         Q_EMIT q->ipV4AddressChanged();
@@ -335,7 +338,7 @@ void NetworkManager::DevicePrivate::propertyChanged(const QString &property, con
         metered = NetworkManager::DevicePrivate::convertMeteredStatus(value.toUInt());
         Q_EMIT q->meteredChanged(metered);
     } else {
-        qCWarning(NMQT) << Q_FUNC_INFO << "Unhandled property" << property;
+        qCDebug(NMQT) << Q_FUNC_INFO << "Unhandled property" << property;
     }
 }
 
@@ -501,6 +504,12 @@ bool NetworkManager::Device::managed() const
     return d->managed;
 }
 
+uint NetworkManager::Device::interfaceFlags() const
+{
+    Q_D(const Device);
+    return d->interfaceFlags;
+}
+
 uint NetworkManager::Device::mtu() const
 {
     Q_D(const Device);
