@@ -25,7 +25,7 @@
 #define NETWORKMANAGERQT_DEVICE_H
 
 #include <QObject>
-#include <QtCore/QtGlobal>
+#include <QtGlobal>
 #include <QSharedPointer>
 
 #include <networkmanagerqt/networkmanagerqt_export.h>
@@ -58,6 +58,7 @@ class NETWORKMANAGERQT_EXPORT Device : public QObject
     Q_PROPERTY(QString firmwareVersion READ firmwareVersion)
     Q_PROPERTY(QVariant genericCapabilities READ capabilitiesV)
     Q_PROPERTY(QHostAddress ipV4Address READ ipV4Address)
+    Q_PROPERTY(uint InterfaceFlags READ interfaceFlags)
     Q_PROPERTY(bool managed READ managed)
     Q_PROPERTY(uint mtu READ mtu)
     Q_PROPERTY(bool nmPluginMissing READ nmPluginMissing)
@@ -322,6 +323,10 @@ public:
      * Is the device currently being managed by NetworkManager?
      */
     bool managed() const;
+    /**
+      * The up or down flag for the device
+      */
+    uint interfaceFlags() const;
     /**
      * Is the firmware needed by the device missing?
      */
@@ -507,6 +512,10 @@ Q_SIGNALS:
      * Emitted when the managed state of this network has changed.
      */
     void managedChanged();
+    /**
+      * Emitted when the up or down state of the device changed
+      */
+    void interfaceFlagsChanged();
 
     /**
      * Emitted when the physical port ID changes.
