@@ -21,11 +21,7 @@
 #include "wirelesssecuritysetting.h"
 #include "wirelesssecuritysetting_p.h"
 
-#if !NM_CHECK_VERSION(1, 0, 0)
-#include <nm-setting-wireless-security.h>
-#endif
-
-#include <QtCore/QDebug>
+#include <QDebug>
 
 NetworkManager::WirelessSecuritySettingPrivate::WirelessSecuritySettingPrivate()
     : name(NM_SETTING_WIRELESS_SECURITY_SETTING_NAME)
@@ -445,6 +441,8 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
             setKeyMgmt(WpaPsk);
         } else if (key == "wpa-eap") {
             setKeyMgmt(WpaEap);
+        } else if (key == "sae") {
+            setKeyMgmt(WpaSae);
         }
     }
 
@@ -575,6 +573,8 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "wpa-psk");
     } else if (keyMgmt() == WpaEap) {
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "wpa-eap");
+    } else if (keyMgmt() == WpaSae) {
+        setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "sae");
     }
 
     if (wepTxKeyindex()) {
